==> hoteldruid-mod-pt_2.1.3-2.tar.gz: pt/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Inserir as regras de atribuição para as reservas do ano"; break;
case "Regola di assegnazione":  		$messaggio = "Regra de atribuição"; break;
case "nel periodo dal":  			$messaggio = "no período do"; break;
case "al":  					$messaggio = "ao"; break;
case "motivazione":  				$messaggio = "Motivação"; break;
case "Inserisci la regola":  			$messaggio = "Inserir regra"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Inserir ou modificar a regra"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Apagar todas as regras deste tipo"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "Quando escolher a tarifa"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "se não estiver inserido nenhum outro método de atribuição"; break;
case "Vedi le regole già inserite":  		$messaggio = "Ver regras já inseridas"; break;
case "Torna al menù principale":  		$messaggio = "Voltar ao menu principal"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Não foram inseridos todos os dados necessários"; break;
case "Le date sono sbagliate":  		$messaggio = "As datas estão erradas"; break;
case "opzionale":  				$messaggio = "opcional"; break;
case "La regola è stata inserita":  		$messaggio = "A regra foi inserida"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Você tem certeza que quer apagar todas as regras do tipo 1"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Le regole sono state cancellate":  	$messaggio = "As regras foram apagadas"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Você deve escolher a tarifa"; break;
case " non esiste":  				$messaggio = " não existe"; break;
case "La regola di assegnazione":		$messaggio = "A regra de atribuição"; break;
case "è stata inserita":			$messaggio = "foi inserida"; break;
case "è stata modificata":			$messaggio = "foi alterada"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Motivazione non valida":  		$messaggio = "Motivação inválida"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "A tarifa escolhida já tem um usuário atribuído. Apague a regra antes de inserir uma nova"; break;
case "Quando l'utente amministratore":  	$messaggio = "Quando o usuário administrador"; break;
case "sceglie la tariffa":  			$messaggio = "escolher a tarifa"; break;
case "fai risultare come se l'utente":  	$messaggio = "mostrar como se o usuário"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "tivesse inserido a reserva e o eventual cliente"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Você deve escolher o usuário para associar"; break;
case "L'utente ":  				$messaggio = "O usuário "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "atribuir automaticamente como número de pessoas"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "se nenhum outro número estiver inserido"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "A tarifa escolhida já tem um número de pessoas atribuído. Apague a regra antes de inserir uma nova tarifa"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Você deve escolher o número de pessoas para associar"; break;
case "Eccezioni alla regola":  			$messaggio = "Excepções à regra"; break;
case "e mancano meno di":  			$messaggio = "e faltam menos de"; break;
case "giorni":					$messaggio = "dias"; break;
case "dall'inizio":				$messaggio = "do começo"; break;
case "dalla fine":				$messaggio = "do fim"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "da reserva quando ele será inserida, então"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Inserir ou alterar esta excepção na regra"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "Você deve adicionar o número de dias"; break;
case "Chiedi prima di assegnare":		$messaggio = "Pergunte antes de atribuir"; break;
case "Chiudi":  				$messaggio = "Fechar"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "O período de fechamento foi libertado de reservas"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">Não foi possível</span> se livrara de todas as reservas no período de fechamento"; break;
case "per le tariffe":  			$messaggio = "pela tarifa"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "Já existe uma regra deste tipo no período escolhido"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.tar.gz: pt/crearegole.php <==
<?php

switch ($messaggio) {

case "Crea Regole":  				$messaggio = "Criar regra"; break;
case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Inserir as regras de atribuição pelas reservas do ano"; break;
case "Regola di assegnazione":  		$messaggio = "Regra de atribuição"; break;
case "nel periodo dal":  			$messaggio = "no período do"; break;
case "al":  					$messaggio = "ao"; break;
case "motivazione":  				$messaggio = "Motivação"; break;
case "Inserisci la regola":  			$messaggio = "Inserir regra"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Inserir ou modificar a regra"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Apagar todas as regras deste tipo"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "Quando escolher a tarifa"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "se não estiver inserido nenhum outro método de atribuição"; break;
case "Vedi le regole già inserite":  		$messaggio = "Ver regras já inseridas"; break;
case "Torna al menù principale":  		$messaggio = "Voltar ao menu principal"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Não foram inseridos todos os dados necessários"; break;
case "Le date sono sbagliate":  		$messaggio = "As datas estão erradas"; break;
case "opzionale":  				$messaggio = "opcional"; break;
case "La regola è stata inserita":  		$messaggio = "A regra foi inserida"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Você tem certeza que quer apagar todas as regras do tipo 1"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Le regole sono state cancellate":  	$messaggio = "As regras foram apagadas"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Você deve escolher a tarifa"; break;
case " non esiste":  				$messaggio = " não existe"; break;
case "La regola di assegnazione":		$messaggio = "A regra de atribuição"; break;
case "è stata inserita":			$messaggio = "foi inserida"; break;
case "è stata modificata":			$messaggio = "foi alterada"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Motivazione non valida":  		$messaggio = "Motivação inválida"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "A tarifa escolhida já tem um usuário atribuído. Apague a regra antes de inserir uma nova"; break;
case "Quando l'utente amministratore":  	$messaggio = "Quando o usuário administrador"; break;
case "sceglie la tariffa":  			$messaggio = "escolher a tarifa"; break;
case "fai risultare come se l'utente":  	$messaggio = "mostrar como se o usuário"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "tivesse inserido a reserva e o eventual cliente"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Você deve escolher o usuário para associar"; break;
case "L'utente ":  				$messaggio = "O usuário "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "atribuir automaticamente como número de pessoas"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "se nenhum outro número estiver inserido"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "A tarifa escolhida já tem um número de pessoas atribuído. Apague a regra antes de inserir uma nova tarifa"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Você deve escolher o número de pessoas para associar"; break;
case "Eccezioni alla regola":  			$messaggio = "Excepções à regra"; break;
case "e mancano meno di":  			$messaggio = "e faltam menos de"; break;
case "giorni":					$messaggio = "dias"; break;
case "dall'inizio":				$messaggio = "do começo"; break;
case "dalla fine":				$messaggio = "do fim"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "da reserva quando ele será inserida, então"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Inserir ou alterar esta excepção na regra"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "Você deve adicionar o número de dias"; break;
case "Chiedi prima di assegnare":		$messaggio = "Pergunte antes de atribuir"; break;
case "Chiudi":  				$messaggio = "Fechar"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "O período de fechamento foi libertado de reservas"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">Não foi possível</span> se livrara de todas as reservas no período de fechamento"; break;
case "per le tariffe":  			$messaggio = "pela tarifa"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "Já existe uma regra deste tipo no período escolhido"; break;
case "assegna automaticamente":  		$messaggio = "atribui automaticamente"; break;
case "tra":  					$messaggio = "entre"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "para atribuir demasiado elevado, superior a que na lista"; break;
case "Attenzione":  				$messaggio = "Atenção"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "da regra 2 faltando na exceção à regra"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "na regra 2 desta tarifa que não podem acomodar"; break;
case "persone":  				$messaggio = "pessoas"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "na regra de atribuição 2 desta tarifa"; break;
case "Regole esistenti":  			$messaggio = "Regras existentes"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Excluir ou redimensionar essas regras"; break;
case "Cancella":  				$messaggio = "Excluir"; break;
case "Ridimensiona":  				$messaggio = "Redimensionar"; break;
case "Modifica la regola":  			$messaggio = "Modificar regra"; break;
case "chiusure":  				$messaggio = "bloqueios"; break;
case "numero di persone":  			$messaggio = "número de pessoas"; break;
case "utente inserimento":  			$messaggio = "entrada do usuário"; break;
case "non permettere l'inserimento di prenotazioni con meno di":	$messaggio = "não permitir a realização de reservas com menos de "; break;
case "Il numero di persone minimo":  		$messaggio = "O número mínimo de pessoas"; break;
case "è maggiore del numero di persone predefinito":	$messaggio = "é maior do que o número pré-definido"; break;
case "è stata cancellata":  			$messaggio = "foi suprimido"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
